# turtlescrape

This is a very simple project to make scraping websites easier so you don't have to type all of the code for the library yourself.

This project uses these libraries: BeautifulSoup4, urllib.request and sys.
